# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def get_call_config() -> Request[abcs.DataJson]:
    _buffer = bytearray(b'\xa9\x1fEU')
    return Request(b'' + _buffer)
def request_call(*, video: bool, user_id: abcs.InputUser, random_id: int, g_a_hash: _bytes, protocol: abcs.PhoneCallProtocol) -> Request[abcs.phone.PhoneCall]:
    _buffer = bytearray(b'\xed\x96\xffB')
    flags = (1 if video else 0)
    _buffer += struct.pack('<I', flags)
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', random_id)
    serialize_bytes_to(_buffer, g_a_hash)
    protocol._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def accept_call(*, peer: abcs.InputPhoneCall, g_b: _bytes, protocol: abcs.PhoneCallProtocol) -> Request[abcs.phone.PhoneCall]:
    _buffer = bytearray(b'\xa0\xb4\xd2;')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, g_b)
    protocol._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def confirm_call(*, peer: abcs.InputPhoneCall, g_a: _bytes, key_fingerprint: int, protocol: abcs.PhoneCallProtocol) -> Request[abcs.phone.PhoneCall]:
    _buffer = bytearray(b'"\x17\xfe.')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, g_a)
    _buffer += struct.pack('<q', key_fingerprint)
    protocol._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def received_call(*, peer: abcs.InputPhoneCall) -> Request[bool]:
    _buffer = bytearray(b'aO\xd5\x17')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def discard_call(*, video: bool, peer: abcs.InputPhoneCall, duration: int, reason: abcs.PhoneCallDiscardReason, connection_id: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xc0\xc1\xcb\xb2')
    flags = (1 if video else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', duration)
    reason._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', connection_id)
    return Request(b'' + _buffer)
def set_call_rating(*, user_initiative: bool, peer: abcs.InputPhoneCall, rating: int, comment: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b"'\xd6\xeaY")
    flags = (1 if user_initiative else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', rating)
    serialize_bytes_to(_buffer, comment.encode('utf-8'))
    return Request(b'' + _buffer)
def save_call_debug(*, peer: abcs.InputPhoneCall, debug: abcs.DataJson) -> Request[bool]:
    _buffer = bytearray(b"~\xddz'")
    peer._write_boxed_to(_buffer)
    debug._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_signaling_data(*, peer: abcs.InputPhoneCall, data: _bytes) -> Request[bool]:
    _buffer = bytearray(b'\x83\x93z\xff')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, data)
    return Request(b'' + _buffer)
def create_group_call(*, rtmp_stream: bool, peer: abcs.InputPeer, random_id: int, title: Optional[str], schedule_date: Optional[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xd8\xc6\xcdH')
    flags = (4 if rtmp_stream else 0) | (0 if title is None else 1) | (0 if schedule_date is None else 2)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', random_id)
    if title is not None:
      serialize_bytes_to(_buffer, title.encode('utf-8'))
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    return Request(b'' + _buffer)
def join_group_call(*, muted: bool, video_stopped: bool, call: abcs.InputGroupCall, join_as: abcs.InputPeer, invite_hash: Optional[str], params: abcs.DataJson) -> Request[abcs.Updates]:
    _buffer = bytearray(b'{\xff2\xb1')
    flags = (1 if muted else 0) | (4 if video_stopped else 0) | (0 if invite_hash is None else 2)
    _buffer += struct.pack('<I', flags)
    call._write_boxed_to(_buffer)
    join_as._write_boxed_to(_buffer)
    if invite_hash is not None:
      serialize_bytes_to(_buffer, invite_hash.encode('utf-8'))
    params._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def leave_group_call(*, call: abcs.InputGroupCall, source: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xf9w\x03P')
    call._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', source)
    return Request(b'' + _buffer)
def invite_to_group_call(*, call: abcs.InputGroupCall, users: Sequence[abcs.InputUser]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'`19{')
    call._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(users))
    for _t0 in users:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def discard_group_call(*, call: abcs.InputGroupCall) -> Request[abcs.Updates]:
    _buffer = bytearray(b'5qwz')
    call._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def toggle_group_call_settings(*, reset_invite_hash: bool, call: abcs.InputGroupCall, join_muted: Optional[bool]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'=\xb4\xbbt')
    flags = (2 if reset_invite_hash else 0) | (0 if join_muted is None else 1)
    _buffer += struct.pack('<I', flags)
    call._write_boxed_to(_buffer)
    if join_muted is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if join_muted else 0xbc799737))
    return Request(b'' + _buffer)
def get_group_call(*, call: abcs.InputGroupCall, limit: int) -> Request[abcs.phone.GroupCall]:
    _buffer = bytearray(b'\xdbE\x18\x04')
    call._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def get_group_participants(*, call: abcs.InputGroupCall, ids: Sequence[abcs.InputPeer], sources: Sequence[int], offset: str, limit: int) -> Request[abcs.phone.GroupParticipants]:
    _buffer = bytearray(b'\xab\xd8X\xc5')
    call._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(ids))
    for _t0 in ids:
      _t0._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(sources))
    _buffer += struct.pack(f'<{len(sources)}i', *sources)
    serialize_bytes_to(_buffer, offset.encode('utf-8'))
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def check_group_call(*, call: abcs.InputGroupCall, sources: Sequence[int]) -> Request[Sequence[int]]:
    _buffer = bytearray(b'w\xf9\x9c\xb5')
    call._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(sources))
    _buffer += struct.pack(f'<{len(sources)}i', *sources)
    return Request(b'' + _buffer)
def toggle_group_call_record(*, start: bool, video: bool, call: abcs.InputGroupCall, title: Optional[str], video_portrait: Optional[bool]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x08\xc7(\xf1')
    flags = (1 if start else 0) | (4 if video else 0) | (0 if title is None else 2) | (0 if video_portrait is None else 4)
    _buffer += struct.pack('<I', flags)
    call._write_boxed_to(_buffer)
    if title is not None:
      serialize_bytes_to(_buffer, title.encode('utf-8'))
    if video_portrait is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if video_portrait else 0xbc799737))
    return Request(b'' + _buffer)
def edit_group_call_participant(*, call: abcs.InputGroupCall, participant: abcs.InputPeer, muted: Optional[bool], volume: Optional[int], raise_hand: Optional[bool], video_stopped: Optional[bool], video_paused: Optional[bool], presentation_paused: Optional[bool]) -> Request[abcs.Updates]:
    _buffer = bytearray(b"\xbf:'\xa5")
    flags = (0 if muted is None else 1) | (0 if volume is None else 2) | (0 if raise_hand is None else 4) | (0 if video_stopped is None else 8) | (0 if video_paused is None else 16) | (0 if presentation_paused is None else 32)
    _buffer += struct.pack('<I', flags)
    call._write_boxed_to(_buffer)
    participant._write_boxed_to(_buffer)
    if muted is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if muted else 0xbc799737))
    if volume is not None:
      _buffer += struct.pack(f'<i', volume)
    if raise_hand is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if raise_hand else 0xbc799737))
    if video_stopped is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if video_stopped else 0xbc799737))
    if video_paused is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if video_paused else 0xbc799737))
    if presentation_paused is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if presentation_paused else 0xbc799737))
    return Request(b'' + _buffer)
def edit_group_call_title(*, call: abcs.InputGroupCall, title: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\n\xac\xa6\x1c')
    call._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    return Request(b'' + _buffer)
def get_group_call_join_as(*, peer: abcs.InputPeer) -> Request[abcs.phone.JoinAsPeers]:
    _buffer = bytearray(b':!|\xef')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def export_group_call_invite(*, can_self_unmute: bool, call: abcs.InputGroupCall) -> Request[abcs.phone.ExportedGroupCallInvite]:
    _buffer = bytearray(b'\x7fd\xaa\xe6')
    flags = (1 if can_self_unmute else 0)
    _buffer += struct.pack('<I', flags)
    call._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def toggle_group_call_start_subscription(*, call: abcs.InputGroupCall, subscribed: bool) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xe64\x9c!')
    call._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', subscribed)
    return Request(b'' + _buffer)
def start_scheduled_group_call(*, call: abcs.InputGroupCall) -> Request[abcs.Updates]:
    _buffer = bytearray(b'B\xe3\x80V')
    call._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def save_default_group_call_join_as(*, peer: abcs.InputPeer, join_as: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'\x8c\x1f^W')
    peer._write_boxed_to(_buffer)
    join_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def join_group_call_presentation(*, call: abcs.InputGroupCall, params: abcs.DataJson) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xc4k\xea\xcb')
    call._write_boxed_to(_buffer)
    params._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def leave_group_call_presentation(*, call: abcs.InputGroupCall) -> Request[abcs.Updates]:
    _buffer = bytearray(b'D\xd1P\x1c')
    call._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_group_call_stream_channels(*, call: abcs.InputGroupCall) -> Request[abcs.phone.GroupCallStreamChannels]:
    _buffer = bytearray(b'@\x19\xb2\x1a')
    call._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_group_call_stream_rtmp_url(*, peer: abcs.InputPeer, revoke: bool) -> Request[abcs.phone.GroupCallStreamRtmpUrl]:
    _buffer = bytearray(b'\xbf\xab\xb3\xde')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', revoke)
    return Request(b'' + _buffer)
def save_call_log(*, peer: abcs.InputPhoneCall, file: abcs.InputFile) -> Request[bool]:
    _buffer = bytearray(b'\x86\x87$A')
    peer._write_boxed_to(_buffer)
    file._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
